@@ -64,16 +64,9 @@ type output
   (** Output mode *)
 
 (** Channel mode *)
-#if ocaml_version >= (3, 13)
 type 'a mode =
   | Input : input mode
   | Output : output mode
-#else
-type 'a mode =
-    private
-  | Input
-  | Output
-#endif
 
 val input : input mode
   (** [input] input mode representation *)
@@ -251,7 +244,7 @@ val read : ?count : int -> input_channel -> string Lwt.t
       returns [""] if the end of input is reached. If [count] is not
       specified, it reads all bytes until the end of input. *)
 
-val read_into : input_channel -> string -> int -> int -> int Lwt.t
+val read_into : input_channel -> Bytes.t -> int -> int -> int Lwt.t
   (** [read_into ic buffer offset length] reads up to [length] bytes,
       stores them in [buffer] at offset [offset], and returns the
       number of bytes read.
@@ -259,7 +252,7 @@ val read_into : input_channel -> string -> int -> int -> int Lwt.t
       Note: [read_into] does not raise [End_of_file], it returns a
       length of [0] instead. *)
 
-val read_into_exactly : input_channel -> string -> int -> int -> unit Lwt.t
+val read_into_exactly : input_channel -> Bytes.t -> int -> int -> unit Lwt.t
   (** [read_into_exactly ic buffer offset length] reads exactly
       [length] bytes and stores them in [buffer] at offset [offset].
 
@@ -294,15 +287,21 @@ val write_line : output_channel -> string -> unit Lwt.t
 val write_lines : output_channel -> string Lwt_stream.t -> unit Lwt.t
   (** [write_lines oc lines] writes all lines of [lines] to [oc] *)
 
-val write_from : output_channel -> string -> int -> int -> int Lwt.t
+val write_from : output_channel -> Bytes.t -> int -> int -> int Lwt.t
   (** [write_from oc buffer offset length] writes up to [length] bytes
       to [oc], from [buffer] at offset [offset] and returns the number
       of bytes actually written *)
 
-val write_from_exactly : output_channel -> string -> int -> int -> unit Lwt.t
+val write_from_string : output_channel -> string -> int -> int -> int Lwt.t
+  (** See {!write}. *)
+
+val write_from_exactly : output_channel -> Bytes.t -> int -> int -> unit Lwt.t
   (** [write_from_exactly oc buffer offset length] writes all [length]
       bytes from [buffer] at offset [offset] to [oc] *)
 
+val write_from_string_exactly : output_channel -> string -> int -> int -> unit Lwt.t
+  (** See {!write_from_exactly}. *)
+
 val write_value : output_channel -> ?flags : Marshal.extern_flags list -> 'a -> unit Lwt.t
   (** [write_value oc ?flags x] marshals the value [x] to [oc] *)
 
@@ -375,30 +374,40 @@ val with_file :
       file and passes the channel to [f]. It is ensured that the
       channel is closed when [f ch] terminates (even if it fails). *)
 
-val open_connection : ?buffer_size : int -> Unix.sockaddr -> (input_channel * output_channel) Lwt.t
-  (** [open_connection ?buffer_size addr] opens a connection to
-      the given address and returns two channels for using it.
+val open_connection :
+  ?fd : Lwt_unix.file_descr ->
+  ?buffer_size : int -> Unix.sockaddr -> (input_channel * output_channel) Lwt.t
+(** [open_connection ?fd ?buffer_size addr] opens a connection to the
+    given address and returns two channels for using it. If [fd] is
+    not specified, a fresh one will be used.
 
-      The connection is completly closed when you close both
-      channels.
+    The connection is completly closed when you close both
+    channels.
 
-      @raise Unix.Unix_error on error.
-  *)
+    @raise Unix.Unix_error on error.
+*)
 
-val with_connection : ?buffer_size : int -> Unix.sockaddr -> (input_channel * output_channel -> 'a Lwt.t) -> 'a Lwt.t
-  (** [with_connection ?buffer_size addr f] opens a connection to
+val with_connection :
+  ?fd : Lwt_unix.file_descr ->
+  ?buffer_size : int ->
+  Unix.sockaddr -> (input_channel * output_channel -> 'a Lwt.t) -> 'a Lwt.t
+(** [with_connection ?fd ?buffer_size addr f] opens a connection to
       the given address and passes the channels to [f] *)
 
 type server
   (** Type of a server *)
 
-val establish_server : ?buffer_size : int -> ?backlog : int -> Unix.sockaddr -> (input_channel * output_channel -> unit) -> server
-  (** [establish_server ?buffer_size ?backlog sockaddr f] creates a
-      server which will listen for incoming connections. New
-      connections are passed to [f]. Note that [f] must not raise any
-      exception.
+val establish_server :
+  ?fd : Lwt_unix.file_descr ->
+  ?buffer_size : int ->
+  ?backlog : int ->
+  Unix.sockaddr -> (input_channel * output_channel -> unit) -> server
+(** [establish_server ?fd ?buffer_size ?backlog sockaddr f] creates a
+    server which will listen for incoming connections. New connections
+    are passed to [f]. Note that [f] must not raise any exception. If
+    [fd] is not specified, a fresh file descriptor will be created.
 
-      [backlog] is the argument passed to [Lwt_unix.listen] *)
+    [backlog] is the argument passed to [Lwt_unix.listen] *)
 
 val shutdown_server : server -> unit
   (** Shutdown the given server *)
@@ -514,8 +523,3 @@ val set_default_buffer_size : int -> unit
 
       @raise Invalid_argument if the given size is smaller than [16]
       or greater than [Sys.max_string_length] *)
-
-(**/**)
-
-val of_string : mode : 'mode mode -> string -> 'mode channel
-  (* Deprecated *)
